/*
Copyright 2019 Cornelius Weig

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package constants

import "github.com/sirupsen/logrus"

const (
	// DefaultLogLevel is set to warn by default.
	DefaultLogLevel = logrus.WarnLevel
)

// Common or shared flags
const (
	FlagVerbs          = "verbs"
	FlagServiceAccount = "sa"
	FlagOutput         = "output"
	FlagVerbosity      = "verbosity"
)

var (
	// ValidVerbs is the list of allowed actions on kubernetes resources.
	// Sort order aligned along CRUD.
	ValidVerbs = []string{
		"create",
		"get",
		"list",
		"watch",
		"update",
		"patch",
		"delete",
		"deletecollection",
	}

	// ValidOutputFormats is the list of valid formats for the result table.
	ValidOutputFormats = []string{
		"icon-table",
		"ascii-table",
	}
)
